<?php
/**
 * @brief randomPost, a plugin for Dotclear 2
 *
 * @package Dotclear
 * @subpackage Plugins
 *
 * @author julien mudry and contributors
 *
 * @copyright julien mudry
 * @copyright GPL-2.0 https://www.gnu.org/licenses/gpl-2.0.html
 */
declare(strict_types=1);

namespace Dotclear\Plugin\randomPost;

use dcCore;
use ArrayObject;
use Dotclear\Helper\Html\Html;
use Dotclear\Helper\Html\Form\Li;
use Dotclear\Helper\Html\Form\Link;
use Dotclear\Helper\Html\Form\Para;
use Dotclear\Helper\Html\Form\Text;
use Dotclear\Helper\Html\Form\Ul;
use Dotclear\Plugin\widgets\WidgetsElement;

class FrontendTemplate
{
    public static function tplRandomPostBlock(ArrayObject $attr, string $content): string
    {
        $categoryID = isset($attr['limit_to_category_id']) ? $attr['limit_to_category_id'] : My::ALL_CAT_ID;
        return '<?php dcCore::app()->ctx->randomPost = new RandomPost(dcCore::app()->blog,true,"'.$categoryID.'"); ?>'.
            $content.
            '<?php unset(dcCore::app()->ctx->randomPost); ?>';
    }

    public static function tplRandomPostTitle(ArrayObject $attr): string
    {
        return '<?php echo context::global_filter(dcCore::app()->ctx->randomPost->getPostTitle(), 1, 1, 0, 0, 0); ?>';
    }

    public static function tplRandomPostURL(ArrayObject $attr): string
    {
        return '<?php echo dcCore::app()->ctx->randomPost->getPostURL(); ?>';
    }

    public static function tplRandomPostExcerpt(ArrayObject $attr): string
    {
        $maxLength = isset($attr['max_length']) ? intval($attr['max_length']) : 200;
        return '<?php if (dcCore::app()->ctx->randomPost->getPost()->isExtended()) {'.
            ' $excerpt = dcCore::app()->ctx->randomPost->getPost()->getExcerpt();'.
            ' } else {'.
            ' $excerpt = dcCore::app()->ctx->randomPost->getPost()->getContent();'.
            ' }'.
            ' if ('.$maxLength.' > 0 && strlen($excerpt) > '.$maxLength.') {'.
            ' $excerpt = substr($excerpt, 0, '.$maxLength.');'.
            ' $excerpt = substr($excerpt, 0, strrpos($excerpt, " "))." ...";'.
            ' }'.
            ' echo $excerpt; ?>';
    }

    public static function tplRandomRedirURL(ArrayObject $attr): string
    {
        $categoryID = isset($attr['limit_to_category_id']) ? '/'.$attr['limit_to_category_id'] : '';
        $f = dcCore::app()->tpl->getFilters($attr);
        return '<?php echo '.sprintf($f, 'dcCore::app()->blog->url.dcCore::app()->url->getBase("randomPost")."'.$categoryID.'"').'; ?>';
    }

    public static function tplRandomStaticURL(ArrayObject $attr): string
    {
        $categoryID = isset($attr['limit_to_category_id']) ? '/'.$attr['limit_to_category_id'] : '';
        $f = dcCore::app()->tpl->getFilters($attr);
        return '<?php echo '.sprintf($f, 'dcCore::app()->blog->url.dcCore::app()->url->getBase("randomStaticPost")."'.$categoryID.'"').'; ?>';
    }

    public static function randomPostWidget(WidgetsElement $w): string
    {
        if ($w->offline) {
            return '';
        }

        if (!$w->checkHomeOnly(dcCore::app()->url->type)) {
            return '';
        }

        $content = '';
        $title = null;
        if ($w->redirect) {
            $title = $w->titleWidget ?: null;
            $linkText = $w->title ? Html::escapeHTML($w->title) : __('Random post');
            $linkUrl = dcCore::app()->blog->url . dcCore::app()->url->getBase('') . My::settings()->randomPostURL;
            if ($w->category != My::ALL_CAT_ID) {
                $linkUrl .= '/' . $w->category;
            }
            $content .= (new Ul())->items([(new Li())->items([
                (new Link())->href($linkUrl)->text($linkText)
            ])])->render();
        } else {
            $title = $w->titleWidget ? $w->titleWidget : ($w->title ?: null);
            $randomPost = new randomPost(dcCore::app()->blog, $w->excerpt, $w->category);
            $content .= (new Para())->items([
                (new Link)->href($randomPost->getURL())->text(Html::escapeHTML($randomPost->getPostTitle()))
            ])->render();
            if ((bool) $w->excerpt) {
                if ($randomPost->getPost()->isExtended()) {
                    $excerpt = $randomPost->getPost()->getExcerpt();
                } else {
                    $excerpt = $randomPost->getPost()->getContent();
                }
                $excerpt = strip_tags($excerpt, $w->allowed_tags);
                $excerpt = preg_replace('/\s+/', ' ', $excerpt);
                $maxLength = intval($w->max_length);
                if ($maxLength > 0 && strlen($excerpt) > $maxLength) {
                    $excerpt = substr($excerpt, 0, $maxLength);
                    $excerpt = substr($excerpt, 0, strrpos($excerpt, ' ')) . ' ...';
                }
                $content .= (new Para())->items([new Text(null, $excerpt)])->render();
            }
        }

        return $w->renderDiv(
            (bool) $w->content_only,
            'randompost ' . $w->class,
            '',
            ($title ? $w->renderTitle(Html::escapeHTML($title)) : '') .
            $content
        );
    }
}
