<?php
/**
 * @brief randomPost, a plugin for Dotclear 2
 *
 * @package Dotclear
 * @subpackage Plugins
 *
 * @author julien mudry and contributors
 *
 * @copyright julien mudry
 * @copyright GPL-2.0 https://www.gnu.org/licenses/gpl-2.0.html
 */
declare(strict_types=1);

namespace Dotclear\Plugin\randomPost;

use dcCore;
use dcUrlHandlers;
use Dotclear\Helper\Network\Http;
use Exception;

class FrontendUrl extends dcUrlHandlers
{
    public static function redirRandomPost(?string $args)
    {
        $args = $args == null ? '' : trim($args, '/');
        if ($args === '') {
            $args = My::ALL_CAT_ID;
        }
        $randomPost = new RandomPost(dcCore::app()->blog, false, $args);

        // Get the URL of the post, and redirect to it
        Http::head(302, 'Found');
        header('Location: '.$randomPost->getURL());
        exit;
    }

    public static function staticRandomPost(?string $args)
    {
        $args = $args === null ? '' : trim($args, '/');
        if ($args === '') {
            $args = My::ALL_CAT_ID;
        }
        $randomPost = new RandomPost(dcCore::app()->blog, false, $args);

        // Get the URL of the post and all associated info
        $params['post_url'] = $randomPost->getPostURL();
        dcCore::app()->ctx->posts = dcCore::app()->blog->getPosts($params);
        if (dcCore::app()->ctx->posts->isEmpty()) {
            # No entry
            self::p404();
        }

        // Prevent the display of the comments form
        dcCore::app()->blog->settings->system->allow_comments = false;

        // Display the post
        self::serveDocument('post.html', 'text/html', false, false);
    }
}
