<?php
/**
 * @brief randomPost, a plugin for Dotclear 2
 *
 * @package Dotclear
 * @subpackage Plugins
 *
 * @author julien mudry and contributors
 *
 * @copyright julien mudry
 * @copyright GPL-2.0 https://www.gnu.org/licenses/gpl-2.0.html
 */
declare(strict_types=1);

namespace Dotclear\Plugin\randomPost;

use dcCore;
use Dotclear\Helper\Html\Html;
use Dotclear\Plugin\widgets\WidgetsStack;

class Widgets
{
    public static function initWidgets(WidgetsStack $widgets): void
    {
        // Get a list of categories in a combo box
        try {
            $rs = dcCore::app()->blog->getCategories();
        } catch (Exception $e) {
            dcCore::app()->error->add($e->getMessage());
        }
        $categories = array(__('All categories') => My::ALL_CAT_ID);
        while ($rs->fetch()) {
            $categories = array_merge($categories, array(Html::escapeHTML($rs->cat_title) => $rs->cat_id));
        }

        $widgets
            ->create('randomPost', My::name(), [FrontendTemplate::class, 'randomPostWidget'], null, __('Link to a random published post'))
            ->setting('titleWidget', __('Title (optional):'), '')
            ->setting('title', __('Link text:'), My::name())
            ->setting('redirect', __('Use redirection'), 1, 'check')
            ->setting('excerpt', __('Display an excerpt from the post'), 0, 'check')
            ->setting('max_length', __('Excerpt maximum length (in characters):'), 200)
            ->setting('allowed_tags', __('HTML tags allowed in the output:'), '')
            ->setting('category', __('Restrict to category:'), 'none', 'combo', $categories)
            ->addHomeOnly()
            ->addContentOnly()
            ->addOffline();
    }
}

/*
if (!defined('DC_RC_PATH')) { return; }

dcCore::app()->addBehavior('initWidgets', array('randomPostBehaviors', 'initWidget'));

require_once __DIR__.'/class.randomPost.php';

class randomPostBehaviors
{
    public static function initWidget(dcWidgets $w)
    {
        $w->create('randomPost', __('Random Post'), array('tplRandomPost', 'randomPostWidget'));
        $w->randomPost->setting('title', __('Title:'), __('Random post'));
        $w->randomPost->setting('redirect', __('Use redirection'), 1, 'check');
        $w->randomPost->setting('excerpt', __('Display an excerpt from the post'), 0, 'check');
        $w->randomPost->setting('max_length', __('Excerpt maximum length (in characters)'), 200);
        $w->randomPost->setting('allowed_tags', __('HTML tags allowed in the output'), '');
        $w->randomPost->setting('homeonly', __('Home page only'), 0, 'check');

        // Get a list of categories in a combo box
        try {
            $rs = dcCore::app()->blog->getCategories();
        } catch (Exception $e) {
            dcCore::app()->error->add($e->getMessage());
        }
        $categories = array(__('All categories') => randomPost::ALL_CAT_ID);
        while ($rs->fetch()) {
            $categories = array_merge($categories, array(html::escapeHTML($rs->cat_title) => $rs->cat_id));
        }
        $w->randomPost->setting('category', __('Restrict to category'), 'none', 'combo', $categories);
    }
}
*/
